# This folder contains teacher HTMLs
These HTMLs can quote images in as follow:

```html
<h3>
Cross Entropy Explained
</h3>
<img src = "{{cross_entropy.jpg}}">
```

Where ```cross_entropy.jpg``` is a image under [static/img](../img) folder.
